@@ -11,7 +11,7 @@ use Linux::DVB::DVBT ;
 
 # VERSION
 our $VERSION = '1.00' ;
-
+our $DEBUG = 0 ;
 
 	# Create application and run it
 	App::Framework->new() ;
@@ -29,9 +29,12 @@ sub app
 {
 	my ($app, $opts_href, $args_href) = @_ ;
 	
-	my %settings = get_config($app) ;
+	$DEBUG = $opts_href->{'debug'} ;
 	
-$app->prt_data("Settings", \%settings) ;
+	my %settings = get_config($app) ;
+	$settings{'perl_lib'} = $opts_href->{'perl_lib'} ;
+	
+$app->prt_data("Settings", \%settings) if $DEBUG ;
 
 	## Must run this script as root
 	if ($>) 
@@ -58,7 +61,7 @@ $app->prt_data("Settings", \%settings) ;
 		['css',		$webowner, 0644],
 		['js',		$webowner, 0644],
 		['php',		$webowner, 0644],
-		['scripts',	$pvrowner, 0755],
+#		['scripts',	$pvrowner, 0755],
 		['tpl',		$webowner, 0644],
 	) ;
 	install_files($app, \%settings, \@dirs) ;
@@ -70,13 +73,19 @@ $app->prt_data("Settings", \%settings) ;
 	start_server($app, \%settings) ;
 	
 	## Do dvb-t scan
-	dvbt_scan($app, \%settings) ;
-	
-	## Set channels
-	dvbt_channels($app, \%settings) ;
-	
-	## Get listings
-	dvbt_listings($app, \%settings) ;
+	if ( dvbt_scan($app, \%settings) )
+	{
+		## Set channels
+		dvbt_channels($app, \%settings) ;
+		
+		## Get listings
+		dvbt_listings($app, \%settings) ;
+		
+	}
+	else
+	{
+		print "!! Please re-run after adding a DVB-T adapter, I can then update the channel information and the EPG !!\n" ;
+	}	
 }
 
 #----------------------------------------------------------------------
@@ -86,6 +95,8 @@ sub create_pvr_user
 {
 	my ($app, $settings_href) = @_ ;
 	
+	print "Creating user ..\n" ;
+	
 	my $user = $settings_href->{'PVR_USER'} ;
 	my $group = $settings_href->{'PVR_GROUP'} ;
 	my $home = $settings_href->{'PVR_HOME'} ;
@@ -113,7 +124,7 @@ sub create_pvr_user
 								-data_re	=> '\@\[dvbt\-update\]' 
 								) ;
 								
-Linux::DVB::DVBT::prt_data("dvbt_blocks=", \@dvbt_blocks) ;
+Linux::DVB::DVBT::prt_data("dvbt_blocks=", \@dvbt_blocks) if $DEBUG ;
 
 	if (!@dvbt_blocks)
 	{
@@ -124,7 +135,7 @@ Linux::DVB::DVBT::prt_data("dvbt_blocks=", \@dvbt_blocks) ;
 				-active		=> 1,
 				-minute 	=> 7,
 				-hour	 	=> 4,
-				-command	=> "$^X $settings_href->{'PVR_ROOT'}/scripts/dvbt-epg-sql.pl >> $settings_href->{'PVR_LOGDIR'}/dvbt_epg.log 2>&1",
+				-command	=> "dvbt-epg-sql >> $settings_href->{'PVR_LOGDIR'}/dvbt_epg.log 2>&1",
 		)) ;
 		$ct->last($block) ;
 
@@ -135,7 +146,7 @@ Linux::DVB::DVBT::prt_data("dvbt_blocks=", \@dvbt_blocks) ;
 				-active		=> 1,
 				-minute 	=> 7,
 				-hour	 	=> 6,
-				-command	=> "$^X $settings_href->{'PVR_ROOT'}/scripts/dvb_record_mgr.pl -dbg-trace all -report 1 >> $settings_href->{'PVR_LOGDIR'}/dvb_record_mgr.log 2>&1",
+				-command	=> "dvbt-record-mgr -dbg-trace all -report 1 >> $settings_href->{'PVR_LOGDIR'}/dvb_record_mgr.log 2>&1",
 		)) ;
 		
 		$ct->last($block) ;
@@ -146,7 +157,7 @@ Linux::DVB::DVBT::prt_data("dvbt_blocks=", \@dvbt_blocks) ;
 	        warn "Error: " . $ct->error . "\n";
 	      };
 
-print "Written crontab\n" ;	      
+		print " * Written crontab\n" ;	      
 	      
 	}
 }
@@ -159,6 +170,8 @@ sub create_database
 {
 	my ($app, $settings_href) = @_ ;
 
+	print "Setting up MySQL ..\n" ;
+	
 	## Check for user
 	my $temp0 = "tmp0-$$.sql" ;
 	open my $fh, ">$temp0" or die "Error: Unable to create temp file : $!" ;
@@ -192,6 +205,7 @@ SQL
 	open my $fh, ">$temp1" or die "Error: Unable to create temp file : $!" ;
 	if ($create_user)
 	{
+		print " * Create user $settings_href->{SQL_USER}\n" ;
 		print $fh <<SQL ;
 	
 CREATE USER '$settings_href->{SQL_USER}'\@'localhost' IDENTIFIED BY  '$settings_href->{SQL_PASSWORD}';
@@ -204,6 +218,7 @@ SQL
 	}
 	else
 	{
+		print " * Update user $settings_href->{SQL_USER}\n" ;
 		print $fh <<SQL ;
 	
 SET PASSWORD FOR '$settings_href->{SQL_USER}'\@'localhost' = PASSWORD('$settings_href->{SQL_PASSWORD}') ;
@@ -239,10 +254,13 @@ SQL
 	close $fh ;
 
 	my $got_listings = 0 ;
-	$app->run("mysql -uroot -p$settings_href->{SQL_ROOT_PASSWORD} < $temp0") ;
+	$app->run(
+		'cmd' 		=> "mysql -uroot -p$settings_href->{SQL_ROOT_PASSWORD} < $temp3",
+		'on_error'	=> 'status',
+	) ;
 	my $results_aref = $app->run()->results ;
 	my $status = $app->run()->status ;
-	if (!$status)
+	if ($status == 0)
 	{
 		if (@$results_aref)
 		{
@@ -282,10 +300,13 @@ SQL
 		}
 	}
 	
+	unless ($DEBUG)
+	{
 	unlink $temp0 ;
 	unlink $temp1 ;
 	unlink $temp2 if $temp2 ;
 	unlink $temp3 ;
+	}
 }
 
 
@@ -428,7 +449,7 @@ sub template_files
 		
 		# read
 		local $/ ;
-		open my $fh, "<install/$src" or die "Error: unable to read template $src : $!" ;
+		open my $fh, "<$src" or die "Error: unable to read template $src : $!" ;
 		my $data = <$fh> ;
 		close $fh ;
 		
@@ -452,7 +473,7 @@ sub template_files
 		chown $uid, $gid, $dest ;
 		chmod $mode, $dest ;
 		
-print "\nSet $dest owner $uid:$gid  mode $mode\n" ;
+print "\nSet $dest owner $uid:$gid  mode $mode\n" if $DEBUG ;
 		print "done\n" ;
 		
 	}	
@@ -477,22 +498,33 @@ sub dvbt_scan
 	print "Initialising DVB-T ..\n" ;
 	
 	## Create dvb 
-	my $dvb = Linux::DVB::DVBT->new() ;
-	my $tuning_href = $dvb->get_tuning_info() ;
-#Linux::DVB::DVBT::prt_data("Current tuning info=", $tuning_href) ;
-	$dvb = undef ;
-	
-	if ($tuning_href)
+	my $dvb = Linux::DVB::DVBT->new('errmode' => 'return') ;
+	my @devices = $dvb->devices() ;
+	if (@devices < 1) 
 	{
-		print " * DVB-T already initialised, skipping\n" ;
+		print " ** No DVB adapters found, skipping **\n" ;
+		return 0 ;
 	}
 	else
 	{
-		print " * Tuning DVB-T, this may take some time - please wait ..\n" ;
-		system("dvbt-scan $settings_href->{'DVBT_FREQFILE'}") ;
+	
+		my $tuning_href = $dvb->get_tuning_info() ;
+	#Linux::DVB::DVBT::prt_data("Current tuning info=", $tuning_href) ;
+		$dvb = undef ;
+		
+		if ($tuning_href)
+		{
+			print " * DVB-T already initialised, skipping\n" ;
+		}
+		else
+		{
+			print " * Tuning DVB-T, this may take some time - please wait ..\n" ;
+			system("dvbt-scan $settings_href->{'DVBT_FREQFILE'}") ;
+		}
+	
 	}
 	
-	
+	return 1 ;
 }
 
 #----------------------------------------------------------------------
@@ -501,7 +533,7 @@ sub dvbt_channels
 	my ($app, $settings_href) = @_ ;
 
 	print "Updating DVB-T channels ..\n" ;
-	system("$^X $settings_href->{'PVR_ROOT'}/scripts/dvbt-chans-sql.pl ")
+	$app->run("dvbt-chans-sql ")
 	
 }
 
@@ -545,7 +577,7 @@ SQL
 	else
 	{
 		print "Gathering DVB-T listings (please wait) ..\n" ;
-		system("$^X $settings_href->{'PVR_ROOT'}/scripts/dvbt-epg-sql.pl") ;
+		system("dvbt-epg-sql") ;
 	}
 
 	unlink $temp0 ;
@@ -587,6 +619,11 @@ __DATA__
 
 Installs the Quartz PVR 
 
+[OPTIONS]
+
+-perl_lib=s		Perl library path
+
+Set to the Perl library path where the pure perl modules will be installed
 
 __DATA__ sql
 
@@ -776,13 +813,14 @@ AUDIO_DIR = /served/stories
 DATABASE = quartzpvr
 DATE_TZ = TZ=GMT
 DVBT_FREQFILE = /usr/share/dvb/dvb-t/uk-Oxford
+MAIL_TO = linux@quartz-net.co.uk
 PERL_BIN = /usr/bin/perl
 PVR_GROUP = video
 PVR_LOGDIR = /var/log/quartzpvr
 PVR_ROOT = /var/www/quartzpvr
 PVR_USER = quartzpvr
 SERVER_PORT = 21328
-SQL_PASSWORD = qp30763
+SQL_PASSWORD = qp16902
 SQL_ROOT_PASSWORD = zzsqlroot
 SQL_USER = quartzpvr
 VIDEO_DIR = /served/videos/PVR
